/*
    Copyright  1995-2001, The AROS Development Team. All rights reserved.
    $Id: setfilter.c,v 1.1.1.1 2005/03/15 15:57:28 laire Exp $
 
    Desc:
    Lang: English
*/

/*****************************************************************************
 
    NAME */

#include "cxintern.h"
#include <libraries/commodities.h>
#include <proto/exec.h>
#include <proto/commodities.h>

#define DEBUG_SETFILTER(x)	
#define DEBUG_BADFILTER(x)	x;

AROS_LH2(VOID, SetFilter,

         /*  SYNOPSIS */

         AROS_LHA(CxObj *, filter, A0),
         AROS_LHA(STRPTR,  text,   A1),

         /*  LOCATION */

         struct Library *, CxBase, 20, Commodities)

/*  FUNCTION
 
    Make 'filter' match events of the type specified in 'text'.
 
    INPUTS
 
    filter  -  the commodity filter the matching conditions of which to set
    text    -  description telling what to filter
 
    RESULT
 
    The internal error field will be updated (COERR_BADFILTER) according to
    the success or failure of the operation.
 
    NOTES
 
    EXAMPLE
 
    BUGS
 
    SEE ALSO
 
    SetFilterIX(), CxObjError()
 
    INTERNALS
 
    HISTORY
 
******************************************************************************/

{
	AROS_LIBFUNC_INIT

	DEBUG_SETFILTER(dprintf("SetFilter: filter 0x%lx text '%s'\n",
	                          filter,text ? text : ""));

	if (filter == NULL)
	{
		return;
	}

	ObtainSemaphore(&GPB(CxBase)->cx_SignalSemaphore);

	if (CXOBJType(filter) == CX_FILTER)
	{
		LONG err;

		err = ParseIX(text, filter->co_Ext.co_FilterIX);

		if (err == 0 || err == -2)
		{
			filter->co_Error &= ~COERR_BADFILTER;
		}
		else
		{
			DEBUG_BADFILTER(dprintf("SetFilter: Bad filter \"%s\"!\n", text));
			filter->co_Error |= COERR_BADFILTER;
		}
	}
	else
	{
		filter->co_Error |= COERR_BADTYPE;
	}

	ReleaseSemaphore(&GPB(CxBase)->cx_SignalSemaphore);

	DEBUG_SETFILTER(dprintf("SetFilter: Leaving... -> filter->co_Error 0x%lx\n",filter->co_Error));

	AROS_LIBFUNC_EXIT
} /* SetFilter */
